@@ -10,9 +10,11 @@ use crate::auth::CurrentUser;
 use crate::listing::{Breadcrumb, Entry, QueryParameters, SortingMethod, SortingOrder};
 use crate::{archive::ArchiveMethod, MiniserveConfig};
 
+#[allow(clippy::too_many_arguments)]
 /// Renders the file listing
 pub fn page(
     entries: Vec<Entry>,
+    readme: Option<(String, String)>,
     is_root: bool,
     query_params: QueryParameters,
     breadcrumbs: Vec<Breadcrumb>,
@@ -165,6 +167,12 @@ pub fn page(
                             }
                         }
                     }
+                    @if let Some(readme) = readme {
+                        div {
+                            h3 { (readme.0) }
+                            (PreEscaped (readme.1));
+                        }
+                    }
                     a.back href="#top" {
                         (arrow_up())
                     }
